@@ -1030,7 +1030,7 @@ aiieee::zlopp("zlopp");
 aiieee::reset_zlopp();
 print "ok\n" if aiieee::zlopp("zlopp");'
 tests[253]='use Unicode::UCD q/prop_invmap/; my @list = prop_invmap("Uppercase_Mapping"); print "ok"'
-tests[2530]='INIT{require "t/test.pl"}plan(tests=>2);is("\x{2665}", v9829);is(v9829,"\x{2665}");'
+tests[2530]='INIT{require "t/TestBC.pm"}plan(tests=>2);is("\x{2665}", v9829);is(v9829,"\x{2665}");'
 result[2530]='1..2
 ok 1
 ok 2'
@@ -1411,6 +1411,10 @@ tests[3300]='#WONTFIX
 tests[3301]='#WORKAROUND 3300
 IO::Handle->new if $ENV{none}; *STDOUT; sub IO::Handle::self { $_[0] };
 (*STDOUT->self . "") =~ m/^GLOB/ and print "ok\n"'
+tests[367]='#BROKEN since 5.22 (METHOP for binc)
+use Math::BigInt;
+my $x = Math::BigInt->new('1' x 20);
+print "ok" if ++$x eq "11111111111111111112";'
 
 init
 
